@@ -13,62 +13,18 @@ Moonshine::Parser - Parsed
 
 =head1 VERSION
 
-Version 0.04
+Version 0.05
 
 =cut
 
-our $VERSION = '0.04';
+our $VERSION = '0.05';
 
 =head1 SYNOPSIS
 
     use Moonshine::Parser;
 
     my $parser = Moonshine::Parser->new();
-    my $moonshine_element = $parser->parse('html', $html);
-
-=head1 SUBROUTINES/METHODS
-
-=head2 parse
-
-    $self->parse($type, $string);
-
-Parse html into a Moonshine::Element.
-
-=head2 parse_file
-    
-    $self->parse_file($type, $file);
-
-=cut
-
-=head2 parse_html
-
-    $self->parse_html($string);
-
-Parse html into a Moonshine::Element.
-
-=cut
-
-=head2 parse_html_file
-
-    $self->parse_html_file($file);
-
-Parse a file that contains html into a Moonshine::Element.
-
-=cut
-
-=head2 parse_pod
-
-    $self->parse_pod($string);
-
-Parse pod into a Moonshine::Element.
-
-=cut
-
-=head2 parse_pod_file
-
-Parse a file that contains pod into a Moonshine::Element.
-
-=cut
+    my $moonshine_element = $parser->parse($html);
 
 =head1 AUTHOR
 
